public interface OWLDataPropertyExpression extends OWLPropertyExpression, SWRLPredicate
| Modifier and Type | Method and Description |
|---|---|
OWLDataProperty |
asOWLDataProperty()
If the property is a named data property then this method will obtain the property as such.
|
accept, accept, isDataPropertyExpression, isObjectPropertyExpression, isOWLBottomDataProperty, isOWLBottomObjectProperty, isOWLTopDataProperty, isOWLTopObjectPropertyaccept, accept, getNestedClassExpressions, isBottomEntity, isIndividual, isIRI, isTopEntity, toStringcompareTogetSignaturecontainsEntityInSignaturegetAnonymousIndividualsgetClassesInSignaturegetObjectPropertiesInSignaturegetDataPropertiesInSignaturegetIndividualsInSignaturegetDatatypesInSignaturegetAnnotationPropertiesInSignatureisAnonymous, isNamed@Nonnull OWLDataProperty asOWLDataProperty()
isAnonymous or the isNamed methods
should first be used to determine if the property is named (i.e. not an object property
expression such as inv(p)). If the property is named then this method may be used to obtain
the property as a named property without casting.OWLDataProperty if possible.OWLRuntimeException - if the property is not a named property.Copyright © 2024 The University of Manchester. All rights reserved.