public interface OWLObjectPropertyExpression extends OWLPropertyExpression, SWRLPredicate
| Modifier and Type | Method and Description |
|---|---|
OWLObjectProperty |
asOWLObjectProperty()
If the property is a named object property then this method will obtain the property as such.
|
OWLObjectPropertyExpression |
getInverseProperty()
Obtains the property that corresponds to the inverse of this property.
|
OWLObjectProperty |
getNamedProperty()
Get the named object property used in this property expression.
|
OWLObjectPropertyExpression |
getSimplified()
Deprecated.
Since it is not legal to apply ObjectInverseOf to anything other than an Object
Property, all object properties are always in the simplified form.
|
accept, accept, isDataPropertyExpression, isObjectPropertyExpression, isOWLBottomDataProperty, isOWLBottomObjectProperty, isOWLTopDataProperty, isOWLTopObjectPropertyaccept, accept, getNestedClassExpressions, isBottomEntity, isIndividual, isIRI, isTopEntity, toStringcompareTogetSignaturecontainsEntityInSignaturegetAnonymousIndividualsgetClassesInSignaturegetObjectPropertiesInSignaturegetDataPropertiesInSignaturegetIndividualsInSignaturegetDatatypesInSignaturegetAnnotationPropertiesInSignatureisAnonymous, isNamed@Nonnull OWLObjectProperty asOWLObjectProperty()
isAnonymous or isNamed methods should
first be used to determine if the property is named (i.e. not an object property expression
such as inv(p)). If the property is named then this method may be used to obtain the property
as a named property without casting.OWLObjectProperty if possible.OWLRuntimeException - if the property is not a named property.@Nonnull OWLObjectPropertyExpression getInverseProperty()
@Deprecated @Nonnull OWLObjectPropertyExpression getSimplified()
@Nonnull OWLObjectProperty getNamedProperty()
Copyright © 2024 The University of Manchester. All rights reserved.